
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
      <script>
import extend from "@/extension/inbound/receiveOrder.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "receiveOrderId",
      footer: "Foots",
      cnName: "收货单",
      name: "receiveOrder",
      url: "/ReceiveOrder/",
      sortName: "receiveOrderId",
    });

    const searchFormFields = ref({
      receiveOrderNo: "",
      receiveOrderType: "",
      receiveOrderStatus: "",
      creater: "",
    });
    const searchFormOptions = ref([
      [
        { title: "单据编号", field: "receiveOrderNo", type: "like" },
        {
          title: "单据类型",
          field: "receiveOrderType",
          type: "select",
          dataKey: "receiveOrderTypeEnum",
          data: [],
        },
        {
          title: "单据状态",
          field: "receiveOrderStatus",
          type: "selectList",
          dataKey: "receiveStatus",
          data: [],
        },
      ],
      [
        { title: "供应商", field: "suppliersId", type: "select",dataKey:"suppliers",data:[]},
        { title: "创建者", field: "creater", type: "like" }
      ],
    ]);

    const editFormFields = ref({
      receiveOrderNo: "",
      receiveOrderType: "",
      suppliersId: "",
      warehouseId: "",
      deliveryCode: "",
    });
    const editFormOptions = ref([
      [
        {
          field: "receiveOrderNo",
          title: "单据编号",
          type: "string",
          readonly: "true",
        },
        {
          title: "单据类型",
          required: true,
          field: "receiveOrderType",
          type: "select",
          dataKey: "receiveOrderTypeEnum",
          data: [],
        },
        {
          title: "供应商",
          field: "suppliersId",
          type: "select",
          dataKey: "suppliers",
          data: [],
          required: true,
        },
        {
          title: "仓库",
          field: "warehouseId",
          type: "select",
          dataKey: "warehouses",
          data: [],
          required: true,
        },
      ],
      [
        {
          title: "送货单号",
          field: "deliveryCode",
          type: "string",
        },
      ],
    ]);
    const columns = ref([
      {
        field: "receiveOrderId",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "receiveOrderNo",
        title: "收货单号",
        type: "string",
        width: 150,
        align: "left",
        link: true,
      },
      {
        field: "receiveOrderType",
        title: "订单类型",
        type: "string",
        width: 150,
        align: "left",
        bind: { key: "receiveOrderTypeEnum", data: [] },
      },
      {
        field: "receiveOrderStatus",
        title: "订单状态",
        type: "string",
        width: 120,
        align: "left",
        bind: { key: "receiveStatus", data: [] },
      },
      {
        field: "customerId",
        title: "客户代号",
        type: "string",
        width: 90,
        align: "left",
        hidden:true
      },
      {
        field: "suppliersId",
        title: "供应商代号",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "warehouseId",
        title: "仓库",
        type: "string",
        width: 90,
        align: "left",
        bind:{key: "warehouses", data: []}
      },
      {
        field: "receiveDate",
        title: "收货日期",
        type: "string",
        width: 160,
        align: "left",
      },
      {
        field: "deliveryCode",
        title: "送货单号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "uploadStatus",
        title: "上传状态",
        type: "string",
        width: 90,
        align: "left",
        bind:{key:"enable",data:[]}
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "收货单明细",
      table: "Dt_ReceiveOrderDetail",
      columns: [
        {
          field: "id",
          title: "Id",
          type: "int",
          width: 90,
          hidden: true,
          readonly: true,
          require: true,
          align: "left",
        },
        {
          field: "receiveOrderId",
          title: "收货单主键",
          type: "string",
          width: 90,
          align: "left",
          hidden: true,
        },
        {
          field: "purchaseOrderDetailRowNo",
          title: "采购单明细行号",
          type: "string",
          width: 60,
          align: "left",
        },
        {
          field: "purchaseOrderNo",
          title: "采购单号",
          type: "select",
          width: 160,
          align: "left",
          required: true,
        },
        {
          field: "materielCode",
          title: "物料编号",
          type: "select",
          width: 150,
          align: "left",
          required: true,
        },
        {
          field: "materielName",
          title: "物料名称",
          type: "string",
          width: 100,
          align: "left",
        },
        {
          field: "materielSpec",
          title: "物料规格",
          type: "select",
          type: "string",
          width: 100,
          align: "left",
        },
        {
          field: "lotNo",
          title: "批次号",
          type: "decimal",
          width: 90,
          align: "left",
          required: true,
        },
        {
          field: "receivedQuantity",
          title: "收货数量",
          type: "decimal",
          width: 90,
          align: "left",
          required: true,
        },
        {
          field: "ifInspection",
          title: "是否检验",
          type: "int",
          width: 90,
          align: "left",
          bind: { key: "enable", data: [] },
        },
        {
          field: "priceInTax",
          title: "含税价格",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "taxRate",
          title: "税率",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "unit",
          title: "单位",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "creater",
          title: "创建人",
          type: "string",
          width: 90,
          align: "left",
        },
        {
          field: "createDate",
          title: "创建时间",
          type: "datetime",
          width: 160,
          align: "left",
        },
        {
          field: "modifier",
          title: "修改人",
          type: "string",
          width: 100,
          align: "left",
        },
        {
          field: "modifyDate",
          title: "修改时间",
          type: "datetime",
          width: 160,
          align: "left",
        },
        {
          field: "remark",
          title: "备注",
          type: "string",
          width: 100,
          align: "left",
        },
      ],
      sortName: "id",
      key: "id",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
      